summaryrefslogtreecommitdiff
path: root/include/svx
diff options
context:
space:
mode:
Diffstat (limited to 'include/svx')
-rw-r--r--include/svx/nbdtmg.hxx2
-rw-r--r--include/svx/svdetc.hxx6
-rw-r--r--include/svx/svdmodel.hxx16
-rw-r--r--include/svx/svdtrans.hxx6
4 files changed, 15 insertions, 15 deletions
diff --git a/include/svx/nbdtmg.hxx b/include/svx/nbdtmg.hxx
index 0a1d716b4c03..e87b9b8fba72 100644
--- a/include/svx/nbdtmg.hxx
+++ b/include/svx/nbdtmg.hxx
@@ -186,7 +186,7 @@ class SVX_DLLPUBLIC NBOTypeMgrBase
public:
NBOTypeMgrBase()
: pSet(nullptr)
- , eCoreUnit(MAP_TWIP)
+ , eCoreUnit(MapUnit::MapTwip)
, aNumCharFmtName(OUString())
, bIsLoading(false)
{}
diff --git a/include/svx/svdmodel.hxx b/include/svx/svdmodel.hxx
index e07d8e754883..4518a83d1a85 100644
--- a/include/svx/svdmodel.hxx
+++ b/include/svx/svdmodel.hxx
@@ -328,15 +328,15 @@ public:
void SetPersist( ::comphelper::IEmbeddedHelper *p ) { m_pEmbeddedHelper = p; }
// Unit for the symbol coordination
- // Default is 1 logical unit = 1/100mm (Unit=MAP_100TH_MM, Fract=(1,1)).
+ // Default is 1 logical unit = 1/100mm (Unit=MapUnit::Map100thMM, Fract=(1,1)).
// Examples:
- // MAP_POINT, Fraction(72,1) : 1 log Einh = 72 Point = 1 Inch
- // MAP_POINT, Fraction(1,20) : 1 log Einh = 1/20 Point = 1 Twip
- // MAP_TWIP, Fraction(1,1) : 1 log Einh = 1 Twip
- // MAP_100TH_MM, Fraction(1,10) : 1 log Einh = 1/1000mm
- // MAP_MM, Fraction(1000,1) : 1 log Einh = 1000mm = 1m
- // MAP_CM, Fraction(100,1) : 1 log Einh = 100cm = 1m
- // MAP_CM, Fraction(100000,1): 1 log Einh = 100000cm = 1km
+ // MapUnit::MapPoint, Fraction(72,1) : 1 log Einh = 72 Point = 1 Inch
+ // MapUnit::MapPoint, Fraction(1,20) : 1 log Einh = 1/20 Point = 1 Twip
+ // MapUnit::MapTwip, Fraction(1,1) : 1 log Einh = 1 Twip
+ // MapUnit::Map100thMM, Fraction(1,10) : 1 log Einh = 1/1000mm
+ // MapUnit::MapMM, Fraction(1000,1) : 1 log Einh = 1000mm = 1m
+ // MapUnit::MapCM, Fraction(100,1) : 1 log Einh = 100cm = 1m
+ // MapUnit::MapCM, Fraction(100000,1): 1 log Einh = 100000cm = 1km
// (FWIW: you cannot represent light years).
// The scaling unit is needed for the Engine to serve the Clipboard
// with the correct sizes.
diff --git a/include/svx/svdtrans.hxx b/include/svx/svdtrans.hxx
index 440c821ffcd5..2c96e13916b6 100644
--- a/include/svx/svdtrans.hxx
+++ b/include/svx/svdtrans.hxx
@@ -261,12 +261,12 @@ SVX_DLLPUBLIC FrPair GetMapFactor(MapUnit eS, MapUnit eD);
FrPair GetMapFactor(FieldUnit eS, FieldUnit eD);
inline bool IsMetric(MapUnit eU) {
- return (eU==MAP_100TH_MM || eU==MAP_10TH_MM || eU==MAP_MM || eU==MAP_CM);
+ return (eU==MapUnit::Map100thMM || eU==MapUnit::Map10thMM || eU==MapUnit::MapMM || eU==MapUnit::MapCM);
}
inline bool IsInch(MapUnit eU) {
- return (eU==MAP_1000TH_INCH || eU==MAP_100TH_INCH || eU==MAP_10TH_INCH || eU==MAP_INCH ||
- eU==MAP_POINT || eU==MAP_TWIP);
+ return (eU==MapUnit::Map1000thInch || eU==MapUnit::Map100thInch || eU==MapUnit::Map10thInch || eU==MapUnit::MapInch ||
+ eU==MapUnit::MapPoint || eU==MapUnit::MapTwip);
}
inline bool IsMetric(FieldUnit eU) {
diff --git a/include/svx/svdetc.hxx b/include/svx/svdetc.hxx
index 8b3c01e3054e..0ed14863454c 100644
--- a/include/svx/svdetc.hxx
+++ b/include/svx/svdetc.hxx
@@ -80,14 +80,14 @@ public:
// Default FontHeight is 847. The font height uses logical units (MapUnit/MapFraction
// see below for further details). The default setting 847/100mm corresponds to about
- // 24 Point. If e.g. one would use Twips (SetMapUnit(MAP_TWIP)) (20 Twip = 1 Point)
+ // 24 Point. If e.g. one would use Twips (SetMapUnit(MapUnit::MapTwip)) (20 Twip = 1 Point)
// instead, one would need to set the font height to 480, in order to get a 24 Point height.
static size_t GetFontHeight() { return GetDefaults().nFontHeight; }
// The MapMode is needed for the global Outliner.
// Incidentally, every newly instantiated SdrModel is assigned this MapMode by default.
- // Default MapUnit is MAP_100TH_MM
- static MapUnit GetMapUnit() { return MAP_100TH_MM; }
+ // Default MapUnit is MapUnit::Map100thMM
+ static MapUnit GetMapUnit() { return MapUnit::Map100thMM; }
// Default MapFraction is 1/1.
static Fraction GetMapFraction() { return GetDefaults().aMapFraction; }